==> serviziopubblico_0.1.0.tar.gz: serviziopubblico-0.1.0/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT
public:
    enum ScreenOrientation {
        ScreenOrientationLockPortrait,
        ScreenOrientationLockLandscape,
        ScreenOrientationAuto
    };

    explicit MainWindow(QWidget *parent = 0);
    virtual ~MainWindow();

    // Note that this will only have an effect on Symbian and Fremantle.
    void setOrientation(ScreenOrientation orientation);

    void showExpanded();

private slots:
    void on_capital_clicked();

    void on_cielo_clicked();

    void on_ditv_clicked();

    void on_kataweb_clicked();

    void on_rtv_clicked();

    void on_telecupole_clicked();

    void on_browserfb_clicked();

    void on_browsertw_clicked();

    void on_actionContattami_triggered();

    void on_actionYoutube_triggered();

    void on_pushButton_22_clicked();

    void on_stream1_clicked();

    void on_down2_clicked();

    void on_stream2_clicked();

    void on_down3_clicked();

    void on_stream3_clicked();

    void on_down4_clicked();

    void on_stream4_clicked();

    void on_down5_clicked();

    void on_stream5_clicked();

    void on_down6_clicked();

    void on_stream6_clicked();

    void on_down7_clicked();

    void on_stream7_clicked();

    void on_down8_clicked();

    void on_stream8_clicked();

    void on_down9_clicked();

    void on_stream9_clicked();

    void on_down10_clicked();

    void on_stream10_clicked();

    void on_down11_clicked();

    void on_stream11_clicked();

    void on_down12_clicked();

    void on_stream12_clicked();

    void on_actionAbout_triggered();

    void on_actionOpzioni_triggered();

    void on_down13_clicked();

    void on_stream13_clicked();

    void on_actionServizioPubblico_Online_triggered();

    void on_actionRicorda_un_amico_triggered();

    void on_actionDonazione_triggered();

private:
    Ui::MainWindow *ui;
};

#endif // MAINWINDOW_H

==> serviziopubblico_0.2.5.tar.gz: serviziopubblico-0.2.5/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>

#include "browser.h"

class PuntateForm;
//class SocialNetwork;
class Credits;
class OptionsForm;
class Browser;
class PuntateMain;

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT
public:
    enum ScreenOrientation {
        ScreenOrientationLockPortrait,
        ScreenOrientationLockLandscape,
        ScreenOrientationAuto
    };

    explicit MainWindow(QWidget *parent = 0);
    virtual ~MainWindow();

    // Note that this will only have an effect on Symbian and Fremantle.
    void setOrientation(ScreenOrientation orientation);

    void showExpanded();

private slots:
    void on_capital_clicked();

    void on_cielo_clicked();

    void on_ditv_clicked();

    void on_kataweb_clicked();

    void on_rtv_clicked();

    void on_telecupole_clicked();

    void on_actionYoutube_triggered();

    void on_actionOpzioni_triggered();

    void on_actionServizioPubblico_Online_triggered();

    void on_actionRicorda_un_amico_triggered();

    void on_actionDonazione_triggered();

    void on_actionPuntate_triggered();

    void on_actionCredits_triggered();

    void on_actionFacebook_triggered();

    void on_actionTwitter_triggered();

    void on_actionVauro_triggered();

private:
    Ui::MainWindow *ui;
    PuntateForm *puntateForm;
    Credits *credits;
    OptionsForm *optionsForm;
    Browser *browser;
    PuntateMain *puntateMain;
};

#endif // MAINWINDOW_H
